Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1138)

Unified Diff: chrome/browser/ui/cocoa/web_dialog_window_controller.h

Issue 10534093: TabContentsWrapper -> TabContents, part 37. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/web_dialog_window_controller.h
diff --git a/chrome/browser/ui/cocoa/web_dialog_window_controller.h b/chrome/browser/ui/cocoa/web_dialog_window_controller.h
index 9b7c8ca15fd53ec48ca83fef0195f396d4a3e7cf..288ad7527ba58be64654c9279330043ce72bf6f7 100644
--- a/chrome/browser/ui/cocoa/web_dialog_window_controller.h
+++ b/chrome/browser/ui/cocoa/web_dialog_window_controller.h
@@ -17,16 +17,15 @@ class Browser;
class WebDialogWindowDelegateBridge;
class Profile;
class TabContents;
-typedef TabContents TabContentsWrapper;
// This controller manages a dialog box with properties and HTML content taken
// from a WebDialogDelegate object.
@interface WebDialogWindowController : NSWindowController<NSWindowDelegate> {
@private
// Order here is important, as tab_contents_ may send messages to
// delegate_ when it gets destroyed.
scoped_ptr<WebDialogWindowDelegateBridge> delegate_;
- scoped_ptr<TabContentsWrapper> contentsWrapper_;
+ scoped_ptr<TabContents> tabContents_;
}
// Creates and shows an WebDialogWindowController with the given
« no previous file with comments | « chrome/browser/ui/cocoa/view_id_util_browsertest.mm ('k') | chrome/browser/ui/cocoa/web_dialog_window_controller.mm » ('j') | no next file with comments »
@@ -17,16 +17,15 @@ class Browser;
- // Order here is important, as tab_contents_ may send messages to
+ // Order here is important, as tabContents_ may send messages to
// delegate_ when it gets destroyed.
scoped_ptr<WebDialogWindowDelegateBridge> delegate_;

Powered by Google App Engine
This is Rietveld 408576698